# edit iptables configure here, run to make permanent

internal=eth1
intaddr=`/sbin/ifconfig $internal`; intaddr=${intaddr#*inet addr:}; intaddr=${intaddr%% *};
external=eth0
extaddr=`/sbin/ifconfig $external`; extaddr=${extaddr#*inet addr:}; extaddr=${extaddr%% *};
if ! [[ $intaddr && $extaddr ]]; then
  echo $internal and $external must be up
else  
  echo "Configuring iptables with internal $internal ($intaddr), external $external ($extaddr)"
  
  # reset
  iptables -F # flush everything
  iptables -t nat -F
  iptables -t mangle -F
  iptables -X # delete user chains
  iptables -Z # zero counters
  
  # default policies  
  iptables -P INPUT DROP 
  iptables -P FORWARD DROP 
  iptables -P OUTPUT ACCEPT
  iptables -t nat -P POSTROUTING ACCEPT
  iptables -t nat -P PREROUTING ACCEPT
  
  # firewall uses nat, allow anything out, expected responses in
  iptables -t nat -A POSTROUTING -o $external -j MASQUERADE
  iptables -A FORWARD -t filter -o $external -j ACCEPT      
  iptables -A FORWARD -t filter -i $external -m state --state RELATED,ESTABLISHED -j ACCEPT
  
  # trust lo and $internal, allow $external expected 
  iptables -A INPUT -i lo -j ACCEPT       
  iptables -A INPUT -i $internal -j ACCEPT     
  iptables -A INPUT -i $external -d $extaddr -m state --state RELATED,ESTABLISHED -j ACCEPT
  
  # ignore fucking script kiddies
  iptables -A INPUT -s 98.210.62.239 -j DROP 
  iptables -A INPUT -s 76.21.122.143 -j DROP 
  iptables -A INPUT -s 67.170.211.42 -j DROP 
  
  # everything else is unsolicited external inbound 
  
  # allow radius
  iptables -A INPUT -p udp -d $extaddr --dport 1645 -j ACCEPT 
  
  # allow incoming ping
  iptables -A INPUT -p icmp -d $extaddr --icmp-type echo-request -j ACCEPT
  
  # ssh is on port 9!!
  iptables -A INPUT -p tcp -d $extaddr --dport 9 --syn -j ACCEPT
  
  # named on 53
  iptables -A INPUT -p udp -d $extaddr --dport 53 -j ACCEPT
  
  # allow DAV
  #iptables -A INPUT -p tcp -d $extaddr --dport 7654 -j ACCEPT
  #iptables -A INPUT -p tcp -d $extaddr --dport 7655 -j ACCEPT
  
  # dump what's left
  iptables -A INPUT -j DROP
  iptables -A FORWARD -j DROP
  
  # save for boot script 
  /etc/init.d/iptables save
fi
